%global url_ver %%(echo %{version} | cut -d. -f1-2)

Summary:        Library providing XML C parser and toolkit 
Name:           libxml2
Version:        2.11.5
Release:        1%{?dist}
License:        MIT
URL:            https://gitlab.gnome.org/GNOME/libxml2/-/wikis/home
Source0:        https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz

Patch0001:      backport-CVE-2023-45322.patch
Patch5000:      5000-update-config-multilib.patch

BuildRequires:  gcc make cmake-rpm-macros git
BuildRequires:  pkgconfig(zlib) pkgconfig(liblzma)

%description
Libxml2 is the XML C parser and toolkit developed for the Gnome project 
(but usable outside of the Gnome platform), it is free software available 
under the MIT License. XML itself is a metalanguage to design markup 
languages, i.e. text language where semantic and structure are added to 
the content using extra "markup" information enclosed between angle brackets. 
HTML is the most well-known markup language. Though the library is written 
in C a variety of language bindings make it available in other environments.

%package devel
Summary:        Libraries, includes, etc. to develop XML and HTML applications
Requires:       %{name} = %{version}-%{release}
Requires:       zlib-devel
Requires:       xz-devel

%description devel
Libraries, include files, etc you can use to develop XML applications.
This library allows to manipulate XML files. It includes support to read, 
modify and write XML and HTML files. 

%package static
Summary:        Static library for libxml2

%description static
Static library for libxml2 provided for specific uses or shaving a few
microseconds when parsing, do not link to them for generic purpose packages.

%package -n python3-%{name}
Summary:        Python 3 bindings for the libxml2 library
BuildRequires:  python3-devel
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-python3 = %{version}-%{release}

%description -n python3-%{name}
The libxml2-python3 package contains a Python 3 module that permits
applications written in the Python programming language, version 3, to use the
interface supplied by the libxml2 library to manipulate XML files.

%prep
%autosetup -n %{name}-%{version} -S git
find doc -type f -executable -print -exec chmod 0644 {} ';'

%build
%configure  \
    --enable-static \
    --with-legacy \
    --with-ftp \
    --with-xptr-locs \
    --with-python=%{__python3} \
    {nil}

%make_build

%install
%make_install

find %{buildroot} -type f -name '*.la' -print -delete
rm -vf %{buildroot}%{python3_sitearch}/*.a
rm -vrf %{buildroot}%{_datadir}/doc/
(cd doc/examples ; make clean ; rm -rf .deps Makefile)
gzip -9 -c doc/libxml2-api.xml > doc/libxml2-api.xml.gz

%check
# There is some wrong in doc test, we skip it
sed -i '/check: check-recursive/d' doc/Makefile
%make_build runtests

%files
%license Copyright
%doc NEWS README.md
%{_libdir}/libxml2.so.2*
%{_bindir}/*
%{_mandir}/*/*

%files devel
%doc doc/*.html
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/libxml2/
%{_datadir}/aclocal/libxml.m4
%{_mandir}/man1/xml2-config.1*
%{_includedir}/libxml2/
%{_bindir}/xml2-config
%{_libdir}/libxml2.so
%{_libdir}/pkgconfig/libxml-2.0.pc
%{_libdir}/cmake/libxml2/

%files static
%license Copyright
%{_libdir}/libxml2.a

%files -n python3-%{name}
%doc doc/*.py
%{python3_sitearch}/libxml2mod.so
%{python3_sitelib}/libxml2.py
%{python3_sitelib}/__pycache__/libxml2.*
%{python3_sitelib}/drv_libxml2.py
%{python3_sitelib}/__pycache__/drv_libxml2.*

%changelog
* Fri Dec 29 2023 Shuo Wang <abushwang@tencent.com> - 2.11.5-1
- update to 2.11.5

* Thu Oct 26 2023 bessiewang <bessiewang@tencent.com> - 2.10.4-4
- Fix CVE-2023-45322

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10.4-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10.4-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 9 2023 Shuo Wang <abushwang@tencent.com> - 2.10.4-1
- downgrade to 2.10.4 due to negative impacts for python-lxml

* Wed Jul 26 2023 Shuo Wang <abushwang@tencent.com> - 2.11.4-1
- update to 2.11.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.14-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.14-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jul 18 2022 jackbertluo <jackbertluo@tencent.com> - 2.9.14-1
- Initial build
